@@ -1,6 +1,10 @@
 
 test_that("extensions installation", {
 
+  # cran tests cannot fail if no network is available
+  skip_on_cran()
+  skip_if_offline()
+
   load_httpfs(nightly=FALSE, force = FALSE)
 
   exts <- duckdb_extensions()
@@ -14,5 +18,7 @@ test_that("extensions installation", {
   expect_true(status$installed)
   expect_equal(status$installed_from, "core")
 
+  load_extension("json")
+
 
 })
